// Scan I2C bus for device responses
#define I2C_TIMEOUT 100
#define I2C_NOINTERRUPT 0
#define I2C_SLOWMODE 1
#define FAC 1
#define I2C_CPUFREQ (F_CPU/FAC)


// Corresponds to A4/A5 - the hardware I2C pins on Arduinos
#define SDA_PORT PORTC
#define SDA_PIN 4
#define SCL_PORT PORTC
#define SCL_PIN 5
#define I2C_FASTMODE 1
#define LED_RED 2       //赤LEDピン
#define LED_BLUE 3      //青LEDピン

#include <SoftI2CMaster.h>
#include <avr/io.h>

//------------------------------------------------------------------------------
void CPUSlowDown(int fac) {
  // slow down processor by a fac
    CLKPR = _BV(CLKPCE);
    CLKPR = _BV(CLKPS1) | _BV(CLKPS0);
}
  
int count = 0;
uint8_t dt[3], dt0[3];
int8_t reg_adr[] = {4, 7, 8};

void setup(void) {
#if FAC != 1
  CPUSlowDown(FAC);
#endif

//  Serial.begin(115200); // change baudrate to 2400 on terminal when low CPU freq!
  pinMode(LED_RED, OUTPUT);
  pinMode(LED_BLUE, OUTPUT);
  digitalWrite(LED_RED, LOW);
  digitalWrite(LED_BLUE, LOW);
  delay(5000);  //ロビの起動を待たせる
}


void loop(void)
{
  uint8_t i2c_adr = 8;

  for (int i = 0; i < 3; i++)
  {
    if (i2c_start(i2c_adr|I2C_WRITE)) {              // スタートコンディションを発行する
          if (i2c_write(reg_adr[i])) {               // レジスタアドレスを指定
               if (i2c_rep_start(i2c_adr|I2C_READ)) { // リピート・スタートコンディションを発行する
                     dt[i] = (char)i2c_read(true) ;
            }
          }
     }
    i2c_stop() ;                                   // ストップコンディションを発行する
  }

  count++;
  for (int i = 0; i < 3; i++)
  {
    if (dt[i] != dt0[i])
    {
      count = 0;
      break;
    }
  }
  if (count == 2) 
  {
    if ((dt[0] == 1) &&  (dt[1] == 2))
    {
      if (dt[2] == 0) 
      {
        digitalWrite(LED_RED, LOW);
        digitalWrite(LED_BLUE, LOW);
      }
      else if (dt[2] == 1) 
      {
        digitalWrite(LED_RED, LOW);
        digitalWrite(LED_BLUE, HIGH);
      }
      else if (dt[2] == 2) 
      {
        digitalWrite(LED_RED, HIGH);
        digitalWrite(LED_BLUE, LOW);
      }       
      else if (dt[2] == 3) 
      {
        digitalWrite(LED_RED, HIGH);
        digitalWrite(LED_BLUE, HIGH);
      } 
    }
  }
  memcpy(dt0, dt, 3);
  delay(100);
}
